import requests
from bs4 import BeautifulSoup

SCRAPER_API_URL = "https://api.scraperapi.com/"
SCRAPER_API_REF = "https://www.scraperapi.com/?fp_ref=enable-fiverr-api"


class Response(requests.Response):
    soup: 'BeautifulSoup'

    def set_soup(self):
        self.soup = BeautifulSoup(self.text, 'html5lib')


class Session(requests.Session):
    def __init__(self):
        super().__init__()
        self.SCRAPER_API_KEY = None
        self.USE_SCRAPER_API = True
        self.country_code = "us"
        self.device_type = "desktop"
        self.session_number = 1

    def request(
            self,
            method,
            url: str = '',
            self_: 'Session' = None,
            *args,
            **kwargs,
    ) -> Response:
        if self_ is None:
            self_ = self

        if self_.USE_SCRAPER_API and not self_.SCRAPER_API_KEY:
            raise ValueError(
                f"No Scraper API key found, please get one from {SCRAPER_API_REF}, and "
                f"use `set_scraper_api_key(` to set it.")
        if self_.SCRAPER_API_KEY and self_.USE_SCRAPER_API:
            kwargs["params"] = {
                "api_key": self_.SCRAPER_API_KEY,
                "url": url,
                "country_code": self_.country_code,
                "device_type": self_.device_type,
                "session_number": self_.session_number,
            }
            url = SCRAPER_API_URL
        response = super().request(method, url, *args, **kwargs)
        response.__class__ = Response
        response.set_soup()
        return response

    def set_scraper_api_key(self, api_key: str):
        self.SCRAPER_API_KEY = api_key

    def set_session_number(self, session_number: int):
        self.session_number = session_number


session = Session()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="cruel",
    version="0.0.11",
    description="Cruel - Scrape everything or anything from the web.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Bishwas-py/cruel",
    author="Bishwas Bhandari",
    author_email="yo@bishwas.net",
    py_modules=["cruel"],
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent"
    ],
    install_requires=[
        "beautifulsoup4 ~= 4.12.2",
        "certifi ~= 2023.7.22",
        "charset-normalizer ~= 3.2.0",
        "html5lib ~= 1.1",
        "idna ~= 3.4",
        "requests ~= 2.31.0",
        "six ~= 1.16.0",
        "soupsieve ~= 2.4.1",
        "urllib3 ~= 2.0.4",
        "webencodings ~= 0.5.1"
    ]
)
